Displaying 16 results from an estimated 16 matches for "5c7b6f0".
Did you mean:
5c7b0
2011 Nov 15
1
[PATCH] virtio-mmio: Correct the name of the guest features selector
...ail.com>
---
Hopefully not too late to fix, should possibly be done in one of the next RCs
since it's user facing.
include/linux/virtio_mmio.h | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)
diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
index 27c7ede..5c7b6f0 100644
--- a/include/linux/virtio_mmio.h
+++ b/include/linux/virtio_mmio.h
@@ -63,7 +63,7 @@
#define VIRTIO_MMIO_GUEST_FEATURES 0x020
/* Activated features set selector - Write Only */
-#define VIRTIO_MMIO_GUEST_FEATURES_SET 0x024
+#define VIRTIO_MMIO_GUEST_FEATURES_SEL 0x024
/* Guest's...
2011 Nov 15
1
[PATCH] virtio-mmio: Correct the name of the guest features selector
...ail.com>
---
Hopefully not too late to fix, should possibly be done in one of the next RCs
since it's user facing.
include/linux/virtio_mmio.h | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)
diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
index 27c7ede..5c7b6f0 100644
--- a/include/linux/virtio_mmio.h
+++ b/include/linux/virtio_mmio.h
@@ -63,7 +63,7 @@
#define VIRTIO_MMIO_GUEST_FEATURES 0x020
/* Activated features set selector - Write Only */
-#define VIRTIO_MMIO_GUEST_FEATURES_SET 0x024
+#define VIRTIO_MMIO_GUEST_FEATURES_SEL 0x024
/* Guest's...
2014 Oct 25
0
[RFC PATCH 1/2] Add a new register offset let interrupt reason available
...remove(struct platform_device *pdev)
{
struct virtio_mmio_device *vm_dev = platform_get_drvdata(pdev);
+ free_pages_exact(vm_dev->isr_mem, PAGE_SIZE);
unregister_virtio_device(&vm_dev->vdev);
return 0;
diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
index 5c7b6f0..b1e3ec7 100644
--- a/include/linux/virtio_mmio.h
+++ b/include/linux/virtio_mmio.h
@@ -95,6 +95,9 @@
/* Device status register - Read Write */
#define VIRTIO_MMIO_STATUS 0x070
+/* Allocate ISRMEM for interrupt reason - Write Only */
+#define VIRTIO_MMIO_ISRMEM 0x080
+
/* The config space is...
2014 Oct 26
0
[RFC PATCH 1/2] Add a new register offset let interrupt reason available
...> struct virtio_mmio_device *vm_dev = platform_get_drvdata(pdev);
>
> + free_pages_exact(vm_dev->isr_mem, PAGE_SIZE);
> unregister_virtio_device(&vm_dev->vdev);
>
> return 0;
> diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
> index 5c7b6f0..b1e3ec7 100644
> --- a/include/linux/virtio_mmio.h
> +++ b/include/linux/virtio_mmio.h
> @@ -95,6 +95,9 @@
> /* Device status register - Read Write */
> #define VIRTIO_MMIO_STATUS 0x070
>
> +/* Allocate ISRMEM for interrupt reason - Write Only */
> +#define VIRTIO_MMIO...
2014 Oct 25
8
[RFC PATCH 0/2] virtio-mmio: add irqfd support for vhost-net based on virtio-mmio
From: Li Liu <john.liuli at huawei.com>
This set of patches try to implemet irqfd support of vhost-net
based on virtio-mmio.
I had posted a mail to talking about the status of vhost-net
on kvm-arm refer to http://www.spinics.net/lists/kvm-arm/msg10804.html.
Some dependent patches are listed in the mail too. Basically the
vhost-net brings great performance improvements, almost 50%+.
2014 Oct 25
8
[RFC PATCH 0/2] virtio-mmio: add irqfd support for vhost-net based on virtio-mmio
From: Li Liu <john.liuli at huawei.com>
This set of patches try to implemet irqfd support of vhost-net
based on virtio-mmio.
I had posted a mail to talking about the status of vhost-net
on kvm-arm refer to http://www.spinics.net/lists/kvm-arm/msg10804.html.
Some dependent patches are listed in the mail too. Basically the
vhost-net brings great performance improvements, almost 50%+.
2015 Jan 20
4
[PATCH v2] virtio-mmio: Update the device to OASIS spec version
...r devices %u!\n",
+ vm_dev->vdev.id.device);
+ return -ENODEV;
+ }
+
+ if (vm_dev->version == 1)
+ writel(PAGE_SIZE, vm_dev->base + VIRTIO_MMIO_GUEST_PAGE_SIZE);
platform_set_drvdata(pdev, vm_dev);
diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
index 5c7b6f0..c4b0968 100644
--- a/include/linux/virtio_mmio.h
+++ b/include/linux/virtio_mmio.h
@@ -51,23 +51,29 @@
/* Virtio vendor ID - Read Only */
#define VIRTIO_MMIO_VENDOR_ID 0x00c
-/* Bitmask of the features supported by the host
+/* Bitmask of the features supported by the device (host)
* (32 bi...
2015 Jan 20
1
[PATCH] virtio-mmio: Update the device to OASIS spec version
...ENDOR_ID);
- writel(PAGE_SIZE, vm_dev->base + VIRTIO_MMIO_GUEST_PAGE_SIZE);
+ if (vm_dev->version == 1)
+ writel(PAGE_SIZE, vm_dev->base + VIRTIO_MMIO_GUEST_PAGE_SIZE);
platform_set_drvdata(pdev, vm_dev);
diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
index 5c7b6f0..c4b0968 100644
--- a/include/linux/virtio_mmio.h
+++ b/include/linux/virtio_mmio.h
@@ -51,23 +51,29 @@
/* Virtio vendor ID - Read Only */
#define VIRTIO_MMIO_VENDOR_ID 0x00c
-/* Bitmask of the features supported by the host
+/* Bitmask of the features supported by the device (host)
* (32 bi...
2015 Jan 20
1
[PATCH] virtio-mmio: Update the device to OASIS spec version
...ENDOR_ID);
- writel(PAGE_SIZE, vm_dev->base + VIRTIO_MMIO_GUEST_PAGE_SIZE);
+ if (vm_dev->version == 1)
+ writel(PAGE_SIZE, vm_dev->base + VIRTIO_MMIO_GUEST_PAGE_SIZE);
platform_set_drvdata(pdev, vm_dev);
diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
index 5c7b6f0..c4b0968 100644
--- a/include/linux/virtio_mmio.h
+++ b/include/linux/virtio_mmio.h
@@ -51,23 +51,29 @@
/* Virtio vendor ID - Read Only */
#define VIRTIO_MMIO_VENDOR_ID 0x00c
-/* Bitmask of the features supported by the host
+/* Bitmask of the features supported by the device (host)
* (32 bi...
2015 Jan 20
0
[PATCH v2] virtio-mmio: Update the device to OASIS spec version
...ice);
> + return -ENODEV;
> + }
> +
> + if (vm_dev->version == 1)
> + writel(PAGE_SIZE, vm_dev->base + VIRTIO_MMIO_GUEST_PAGE_SIZE);
>
> platform_set_drvdata(pdev, vm_dev);
>
> diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
> index 5c7b6f0..c4b0968 100644
> --- a/include/linux/virtio_mmio.h
> +++ b/include/linux/virtio_mmio.h
> @@ -51,23 +51,29 @@
> /* Virtio vendor ID - Read Only */
> #define VIRTIO_MMIO_VENDOR_ID 0x00c
>
> -/* Bitmask of the features supported by the host
> +/* Bitmask of the features s...
2015 Jan 20
0
[PATCH v2] virtio-mmio: Update the device to OASIS spec version
...ice);
> + return -ENODEV;
> + }
> +
> + if (vm_dev->version == 1)
> + writel(PAGE_SIZE, vm_dev->base + VIRTIO_MMIO_GUEST_PAGE_SIZE);
>
> platform_set_drvdata(pdev, vm_dev);
>
> diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
> index 5c7b6f0..c4b0968 100644
> --- a/include/linux/virtio_mmio.h
> +++ b/include/linux/virtio_mmio.h
> @@ -51,23 +51,29 @@
> /* Virtio vendor ID - Read Only */
> #define VIRTIO_MMIO_VENDOR_ID 0x00c
>
> -/* Bitmask of the features supported by the host
> +/* Bitmask of the features s...
2014 Dec 19
5
[RFC] virtio-mmio: Update the device to OASIS spec version
...tform_device *pdev)
{
struct virtio_mmio_device *vm_dev = platform_get_drvdata(pdev);
- unregister_virtio_device(&vm_dev->vdev);
+ if (vm_dev)
+ unregister_virtio_device(&vm_dev->vdev);
return 0;
}
diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
index 5c7b6f0..d5f3634 100644
--- a/include/linux/virtio_mmio.h
+++ b/include/linux/virtio_mmio.h
@@ -51,21 +51,22 @@
/* Virtio vendor ID - Read Only */
#define VIRTIO_MMIO_VENDOR_ID 0x00c
-/* Bitmask of the features supported by the host
+/* Bitmask of the features supported by the device (host)
* (32 bi...
2014 Dec 19
5
[RFC] virtio-mmio: Update the device to OASIS spec version
...tform_device *pdev)
{
struct virtio_mmio_device *vm_dev = platform_get_drvdata(pdev);
- unregister_virtio_device(&vm_dev->vdev);
+ if (vm_dev)
+ unregister_virtio_device(&vm_dev->vdev);
return 0;
}
diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
index 5c7b6f0..d5f3634 100644
--- a/include/linux/virtio_mmio.h
+++ b/include/linux/virtio_mmio.h
@@ -51,21 +51,22 @@
/* Virtio vendor ID - Read Only */
#define VIRTIO_MMIO_VENDOR_ID 0x00c
-/* Bitmask of the features supported by the host
+/* Bitmask of the features supported by the device (host)
* (32 bi...
2015 Jan 15
0
[RFC] virtio-mmio: Update the device to OASIS spec version
...gt;
> - unregister_virtio_device(&vm_dev->vdev);
> + if (vm_dev)
> + unregister_virtio_device(&vm_dev->vdev);
>
Will remove ever be called if probe fails?
> return 0;
> }
> diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
> index 5c7b6f0..d5f3634 100644
> --- a/include/linux/virtio_mmio.h
> +++ b/include/linux/virtio_mmio.h
> @@ -51,21 +51,22 @@
> /* Virtio vendor ID - Read Only */
> #define VIRTIO_MMIO_VENDOR_ID 0x00c
>
> -/* Bitmask of the features supported by the host
> +/* Bitmask of the features s...
2015 Jan 15
0
[RFC] virtio-mmio: Update the device to OASIS spec version
...gt;
> - unregister_virtio_device(&vm_dev->vdev);
> + if (vm_dev)
> + unregister_virtio_device(&vm_dev->vdev);
>
Will remove ever be called if probe fails?
> return 0;
> }
> diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
> index 5c7b6f0..d5f3634 100644
> --- a/include/linux/virtio_mmio.h
> +++ b/include/linux/virtio_mmio.h
> @@ -51,21 +51,22 @@
> /* Virtio vendor ID - Read Only */
> #define VIRTIO_MMIO_VENDOR_ID 0x00c
>
> -/* Bitmask of the features supported by the host
> +/* Bitmask of the features s...
diff --git a/include/linux/virtio_mmio.h b/include/linux/virtio_mmio.h
index 5c7b6f0..c4b0968 100644
--- a/include/linux/virtio_mmio.h
+++ b/include/linux/virtio_mmio.h
@@ -51,23 +51,29 @@
/* Virtio vendor ID - Read Only */
#define VIRTIO_MMIO_VENDOR_ID 0x00c
/* Bitmask of the features supported by the host
* (32 bi...
2015 Jan 20
4
[PATCH v2] virtio-mmio: Update the device to OASIS spec version
...r devices %u!\n",
+ vm_dev->vdev.id.device);
+ return -ENODEV;
+ }
+
+ if (vm_dev->version == 1)
+ writel(PAGE_SIZE, vm_dev->base + VIRTIO_MMIO_GUEST_PAGE_SIZE);
platform_set_drvdata(pdev, vm_dev);
@@ -51,23 +51,29 @@
/* Virtio vendor ID - Read Only */
#define VIRTIO_MMIO_VENDOR_ID 0x00c
-/* Bitmask of the features supported by the host
+/* Bitmask of the features supported by the device (host)
* (32 bi...
2015 Jan 20